@@ -5,16 +5,13 @@ def renumerate(collection):
         yield (index, collection[index])
 
 ### object predicates
-def is_method(obj):
-    return isinstance(obj, MethodType)
 def is_bound_method(obj):
-    return is_method(obj) and obj.im_self is not None
+    return isinstance(obj, MethodType) and obj.im_self is not None
 def is_function(obj):
     return isinstance(obj, FunctionType) or isinstance(obj, BuiltinFunctionType)
 def is_class(obj):
     return isinstance(obj, type) or isinstance(obj, ClassType)
 def is_class_method(obj):
-    im_self = getattr(obj, 'im_self', None)
-    if im_self is None:
+    if not is_bound_method(obj):
         return False
-    return is_class(im_self)
+    return is_class(obj.im_self)
